package GasPipingSystem
  model Network1
    import SI = Modelica.SIunits;
    replaceable package Medium = Modelica.Media.IdealGases.SingleGases.CH4;
    parameter SI.Density rhoN = Medium.density(Medium.setState_pT(101325, 273.15));
    Modelica.Blocks.Sources.RealExpression pA(y = (pipeSA.port_b.p - 101325) / 1000) annotation(
      Placement(visible = true, transformation(origin = {56, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression qSA(y = pipeSA.flowModel.m_flows[1] / rhoN * 3600) annotation(
      Placement(visible = true, transformation(origin = {58, 52}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT governor(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), T = 298.15, nPorts = 1, use_p_in = true) annotation(
      Placement(visible = true, transformation(origin = {-50, 22}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Pipes.StaticPipe pipeSA(redeclare package Medium = Medium, diameter = 0.3, length = 300) annotation(
      Placement(visible = true, transformation(origin = {-18, 22}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.MassFlowSource_T consumerE(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), nPorts = 1, use_m_flow_in = true) annotation(
      Placement(visible = true, transformation(origin = {-2, 56}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Sources.RealExpression pS_Pa(y = pS_kPaG * 1000 + 101325) annotation(
      Placement(visible = true, transformation(origin = {-84, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression qE_kgs(y = -qE_Nm3h * rhoN / 3600) annotation(
      Placement(visible = true, transformation(origin = {-12, 84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    inner Modelica.Fluid.System system annotation(
      Placement(visible = true, transformation(origin = {-40, 84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput pS_kPaG annotation(
      Placement(visible = true, transformation(origin = {-82, 86}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-76, 64}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput qE_Nm3h annotation(
      Placement(visible = true, transformation(origin = {-82, 58}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-74, 36}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput qSA_Nm3h annotation(
      Placement(visible = true, transformation(origin = {86, 52}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {86, 38}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput pA_kPaG annotation(
      Placement(visible = true, transformation(origin = {86, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {86, 66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(pA.y, pA_kPaG) annotation(
      Line(points = {{67, 80}, {86, 80}}, color = {0, 0, 127}));
    connect(qSA.y, qSA_Nm3h) annotation(
      Line(points = {{69, 52}, {86, 52}}, color = {0, 0, 127}));
    connect(qE_kgs.y, consumerE.m_flow_in) annotation(
      Line(points = {{0, 84}, {6, 84}, {6, 66}, {6, 66}}, color = {0, 0, 127}));
    connect(pS_Pa.y, governor.p_in) annotation(
      Line(points = {{-72, 30}, {-64, 30}, {-64, 30}, {-62, 30}}, color = {0, 0, 127}));
    connect(pipeSA.port_b, consumerE.ports[1]) annotation(
      Line(points = {{-8, 22}, {-2, 22}, {-2, 46}}, color = {0, 127, 255}));
    connect(governor.ports[1], pipeSA.port_a) annotation(
      Line(points = {{-40, 22}, {-28, 22}, {-28, 22}, {-28, 22}}, color = {0, 127, 255}));
    annotation(
      Icon(graphics = {Rectangle(origin = {0, 2}, extent = {{-80, 80}, {80, -82}}), Text(origin = {-29, 56}, extent = {{-25, 24}, {-3, 0}}, textString = "pS"), Text(origin = {-32, 26}, extent = {{-26, 26}, {0, 0}}, textString = "qE"), Text(origin = {49, 69}, extent = {{-11, 17}, {13, -19}}, textString = "pA"), Text(origin = {62, 28}, extent = {{-26, 26}, {4, -4}}, textString = "qSA")}, coordinateSystem(initialScale = 0.1)),
      __OpenModelica_simulationFlags(lv = "LOG_STATS", outputFormat = "mat", s = "dassl"));
  end Network1;

  model Network1Test
    Modelica.Blocks.Sources.Constant pA(k = 1.5) annotation(
      Placement(visible = true, transformation(origin = {-50, 36}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant qE(k = 200) annotation(
      Placement(visible = true, transformation(origin = {-48, 4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    GasPipingSystem.Network1 network11 annotation(
      Placement(visible = true, transformation(origin = {4, 18}, extent = {{-28, -28}, {28, 28}}, rotation = 0)));
  equation
    connect(qE.y, network11.qE_Nm3h) annotation(
      Line(points = {{-37, 4}, {-32, 4}, {-32, 28}, {-18, 28}}, color = {0, 0, 127}));
    connect(pA.y, network11.pS_kPaG) annotation(
      Line(points = {{-39, 36}, {-18, 36}}, color = {0, 0, 127}));
    annotation(
      __OpenModelica_simulationFlags(lv = "LOG_STATS", outputFormat = "mat", s = "dassl"));
  end Network1Test;

  model Network2
    import SI = Modelica.SIunits;
    replaceable package Medium = Modelica.Media.IdealGases.SingleGases.CH4;
    parameter SI.Density rhoN = Medium.density(Medium.setState_pT(101325, 273.15));
    Modelica.Blocks.Sources.RealExpression pA(y = (pipeSA.port_b.p - 101325) / 1000) annotation(
      Placement(visible = true, transformation(origin = {56, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression qSA(y = pipeSA.flowModel.m_flows[1] / rhoN * 3600) annotation(
      Placement(visible = true, transformation(origin = {56, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT governor(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), T = 298.15, nPorts = 1, use_p_in = true) annotation(
      Placement(visible = true, transformation(origin = {-50, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Pipes.StaticPipe pipeSA(redeclare package Medium = Medium, diameter = 0.3, length = 300) annotation(
      Placement(visible = true, transformation(origin = {-18, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.MassFlowSource_T consumerE(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), nPorts = 1, use_m_flow_in = true) annotation(
      Placement(visible = true, transformation(origin = {-2, 56}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Sources.RealExpression pS_Pa(y = pS_kPaG * 1000 + 101325) annotation(
      Placement(visible = true, transformation(origin = {-84, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression qE_kgs(y = -qE_Nm3h * rhoN / 3600) annotation(
      Placement(visible = true, transformation(origin = {-12, 84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    inner Modelica.Fluid.System system annotation(
      Placement(visible = true, transformation(origin = {-40, 84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput pS_kPaG annotation(
      Placement(visible = true, transformation(origin = {-82, 86}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-76, 64}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput qE_Nm3h annotation(
      Placement(visible = true, transformation(origin = {-82, 58}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-74, 36}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput qSA_Nm3h annotation(
      Placement(visible = true, transformation(origin = {84, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {86, -16}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput pA_kPaG annotation(
      Placement(visible = true, transformation(origin = {86, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {86, 66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Pipes.StaticPipe pipeAE(redeclare package Medium = Medium, diameter = 0.0216, length = 10, nParallel = 40) annotation(
      Placement(visible = true, transformation(origin = {-2, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
    Modelica.Blocks.Interfaces.RealOutput pE_kPaG annotation(
      Placement(visible = true, transformation(origin = {86, 58}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {84, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression pE(y = (pipeAE.port_b.p - 101325) / 1000) annotation(
      Placement(visible = true, transformation(origin = {58, 58}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression qAE(y = pipeAE.flowModel.m_flows[1] / rhoN * 3600) annotation(
      Placement(visible = true, transformation(origin = {56, -18}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput qAE_Nm3h annotation(
      Placement(visible = true, transformation(origin = {84, -18}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {88, -42}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(qAE.y, qAE_Nm3h) annotation(
      Line(points = {{67, -18}, {84, -18}}, color = {0, 0, 127}));
    connect(qSA.y, qSA_Nm3h) annotation(
      Line(points = {{67, 0}, {84, 0}}, color = {0, 0, 127}));
    connect(pE.y, pE_kPaG) annotation(
      Line(points = {{69, 58}, {79, 58}, {79, 58}, {85, 58}}, color = {0, 0, 127}));
    connect(pipeAE.port_b, consumerE.ports[1]) annotation(
      Line(points = {{-2, 30}, {0, 30}, {0, 48}, {-2, 48}, {-2, 46}}, color = {0, 127, 255}));
    connect(pipeSA.port_b, pipeAE.port_a) annotation(
      Line(points = {{-8, -2}, {-2, -2}, {-2, 10}, {-2, 10}}, color = {0, 127, 255}));
    connect(pS_Pa.y, governor.p_in) annotation(
      Line(points = {{-73, 6}, {-63, 6}, {-63, 6}, {-63, 6}}, color = {0, 0, 127}));
    connect(governor.ports[1], pipeSA.port_a) annotation(
      Line(points = {{-40, -2}, {-34, -2}, {-34, -2}, {-28, -2}, {-28, -2}, {-28, -2}, {-28, -2}, {-28, -2}}, color = {0, 127, 255}));
    connect(pA.y, pA_kPaG) annotation(
      Line(points = {{67, 80}, {86, 80}}, color = {0, 0, 127}));
    connect(qE_kgs.y, consumerE.m_flow_in) annotation(
      Line(points = {{0, 84}, {6, 84}, {6, 66}, {6, 66}}, color = {0, 0, 127}));
    annotation(
      Icon(graphics = {Rectangle(origin = {0, 2}, extent = {{-80, 80}, {80, -82}}), Text(origin = {-29, 56}, extent = {{-25, 24}, {-3, 0}}, textString = "pS"), Text(origin = {-32, 26}, extent = {{-26, 26}, {0, 0}}, textString = "qE"), Text(origin = {49, 69}, extent = {{-11, 17}, {13, -19}}, textString = "pA"), Text(origin = {64, -28}, extent = {{-26, 26}, {4, -4}}, textString = "qSA"), Text(origin = {51, 41}, extent = {{-11, 17}, {13, -19}}, textString = "pE"), Text(origin = {66, -54}, extent = {{-26, 26}, {4, -4}}, textString = "qAE")}, coordinateSystem(initialScale = 0.1)),
      __OpenModelica_simulationFlags(lv = "LOG_STATS", outputFormat = "mat", s = "dassl"));
  end Network2;

  model Network2Test
    Modelica.Blocks.Sources.Constant pA(k = 1.5) annotation(
      Placement(visible = true, transformation(origin = {-50, 36}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant qE(k = 200) annotation(
      Placement(visible = true, transformation(origin = {-48, 4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    GasPipingSystem.Network2 network11 annotation(
      Placement(visible = true, transformation(origin = {4, 18}, extent = {{-28, -28}, {28, 28}}, rotation = 0)));
  equation
    connect(qE.y, network11.qE_Nm3h) annotation(
      Line(points = {{-37, 4}, {-32, 4}, {-32, 28}, {-18, 28}}, color = {0, 0, 127}));
    connect(pA.y, network11.pS_kPaG) annotation(
      Line(points = {{-39, 36}, {-18, 36}}, color = {0, 0, 127}));
    annotation(
      __OpenModelica_simulationFlags(lv = "LOG_STATS", outputFormat = "mat", s = "dassl"));
  end Network2Test;

  model Network4
    import SI = Modelica.SIunits;
    replaceable package Medium = Modelica.Media.IdealGases.SingleGases.CH4;
    parameter SI.Density rhoN = Medium.density(Medium.setState_pT(101325, 273.15));
    Modelica.Blocks.Sources.RealExpression pA(y = (pipeSA.port_b.p - 101325) / 1000) annotation(
      Placement(visible = true, transformation(origin = {76, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression qSA(y = pipeSA.flowModel.m_flows[1] / rhoN * 3600) annotation(
      Placement(visible = true, transformation(origin = {76, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT governor(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), T = 298.15, nPorts = 1, use_p_in = true) annotation(
      Placement(visible = true, transformation(origin = {-60, 14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Pipes.StaticPipe pipeSA(redeclare package Medium = Medium, diameter = 0.3, length = 300) annotation(
      Placement(visible = true, transformation(origin = {-32, 14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.MassFlowSource_T consumerE(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), T = 298.15, nPorts = 1, use_m_flow_in = true) annotation(
      Placement(visible = true, transformation(origin = {-10, 66}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Sources.RealExpression pS_Pa(y = pS_kPaG * 1000 + 101325) annotation(
      Placement(visible = true, transformation(origin = {-90, 22}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression qE_kgs(y = -qE_Nm3h * rhoN / 3600) annotation(
      Placement(visible = true, transformation(origin = {-36, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    inner Modelica.Fluid.System system annotation(
      Placement(visible = true, transformation(origin = {-70, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput pS_kPaG annotation(
      Placement(visible = true, transformation(origin = {-104, 80}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-94, 82}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput qE_Nm3h annotation(
      Placement(visible = true, transformation(origin = {-104, 60}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-92, 52}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput qSA_Nm3h annotation(
      Placement(visible = true, transformation(origin = {106, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-84, -98}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Interfaces.RealOutput pA_kPaG annotation(
      Placement(visible = true, transformation(origin = {106, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, 86}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Pipes.StaticPipe pipeAE(redeclare package Medium = Medium, diameter = 0.0216, length = 10, nParallel = 40) annotation(
      Placement(visible = true, transformation(origin = {-10, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
    Modelica.Blocks.Interfaces.RealOutput pE_kPaG annotation(
      Placement(visible = true, transformation(origin = {106, 26}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, -14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression pE(y = (pipeAE.port_b.p - 101325) / 1000) annotation(
      Placement(visible = true, transformation(origin = {76, 26}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Pipes.StaticPipe pipeAB(redeclare package Medium = Medium, diameter = 0.15, length = 300) annotation(
      Placement(visible = true, transformation(origin = {14, 14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Pipes.StaticPipe pipeBF(redeclare package Medium = Medium, diameter = 0.0216, length = 10, nParallel = 10) annotation(
      Placement(visible = true, transformation(origin = {40, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
    Modelica.Fluid.Sources.MassFlowSource_T consumerF(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), T = 298.15, nPorts = 1, use_m_flow_in = true) annotation(
      Placement(visible = true, transformation(origin = {40, 66}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Interfaces.RealInput qF_Nm3h annotation(
      Placement(visible = true, transformation(origin = {-104, 40}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-92, -44}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression qF_kgs(y = -qF_Nm3h * rhoN / 3600) annotation(
      Placement(visible = true, transformation(origin = {16, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression qAB(y = pipeAB.flowModel.m_flows[1] / rhoN * 3600) annotation(
      Placement(visible = true, transformation(origin = {76, -68}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput qAB_Nm3h annotation(
      Placement(visible = true, transformation(origin = {108, -68}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-58, -98}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Interfaces.RealInput qG_Nm3h annotation(
      Placement(visible = true, transformation(origin = {-102, -20}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-92, 20}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput qH_Nm3h annotation(
      Placement(visible = true, transformation(origin = {-102, -42}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-92, -12}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
    Modelica.Fluid.Pipes.StaticPipe pipeBC(redeclare package Medium = Medium, diameter = 0.15, length = 200) annotation(
      Placement(visible = true, transformation(origin = {40, -10}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Fluid.Sources.MassFlowSource_T consumerG(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), T = 298.15, nPorts = 1, use_m_flow_in = true) annotation(
      Placement(visible = true, transformation(origin = {40, -78}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
    Modelica.Fluid.Pipes.StaticPipe pipeCG(redeclare package Medium = Medium, diameter = 0.0216, length = 10, nParallel = 30) annotation(
      Placement(visible = true, transformation(origin = {40, -52}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Sources.RealExpression qCD(y = pipeCD.flowModel.m_flows[1] / rhoN * 3600) annotation(
      Placement(visible = true, transformation(origin = {76, -98}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression qBC(y = pipeBC.flowModel.m_flows[1] / rhoN * 3600) annotation(
      Placement(visible = true, transformation(origin = {76, -82}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput qBC_Nm3h annotation(
      Placement(visible = true, transformation(origin = {108, -82}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-32, -98}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Fluid.Pipes.StaticPipe pipeCD(redeclare package Medium = Medium, diameter = 0.1, length = 250) annotation(
      Placement(visible = true, transformation(origin = {14, -32}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    Modelica.Fluid.Pipes.StaticPipe pipeDA(redeclare package Medium = Medium, diameter = 0.1, length = 250) annotation(
      Placement(visible = true, transformation(origin = {-10, -10}, extent = {{10, -10}, {-10, 10}}, rotation = -90)));
    Modelica.Fluid.Pipes.StaticPipe pipeDH(redeclare package Medium = Medium, diameter = 0.0216, length = 10, nParallel = 40) annotation(
      Placement(visible = true, transformation(origin = {-10, -52}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Fluid.Sources.MassFlowSource_T consumerH(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), T = 298.15, nPorts = 1, use_m_flow_in = true) annotation(
      Placement(visible = true, transformation(origin = {-10, -78}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
    Modelica.Blocks.Sources.RealExpression qG_kgs(y = -qG_Nm3h * rhoN / 3600) annotation(
      Placement(visible = true, transformation(origin = {14, -94}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression qH_kgs(y = -qH_Nm3h * rhoN / 3600) annotation(
      Placement(visible = true, transformation(origin = {-36, -94}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression pB(y = (pipeAB.port_b.p - 101325) / 1000) annotation(
      Placement(visible = true, transformation(origin = {76, 74}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput pB_kPaG annotation(
      Placement(visible = true, transformation(origin = {106, 74}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, 62}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression pC(y = (pipeBC.port_b.p - 101325) / 1000) annotation(
      Placement(visible = true, transformation(origin = {76, 58}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput pC_kPaG annotation(
      Placement(visible = true, transformation(origin = {106, 58}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, 36}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression pD(y = (pipeCD.port_b.p - 101325) / 1000) annotation(
      Placement(visible = true, transformation(origin = {76, 42}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput pD_kPaG annotation(
      Placement(visible = true, transformation(origin = {106, 42}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, 12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression pF(y = (pipeBF.port_b.p - 101325) / 1000) annotation(
      Placement(visible = true, transformation(origin = {76, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput pF_kPaG annotation(
      Placement(visible = true, transformation(origin = {104, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression pG(y = (pipeCG.port_b.p - 101325) / 1000) annotation(
      Placement(visible = true, transformation(origin = {76, -12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression pH(y = (pipeDH.port_b.p - 101325) / 1000) annotation(
      Placement(visible = true, transformation(origin = {76, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput pG_kPaG annotation(
      Placement(visible = true, transformation(origin = {104, -12}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, -36}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput pH_kPaG annotation(
      Placement(visible = true, transformation(origin = {106, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, -84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput qCD_Nm3h annotation(
      Placement(visible = true, transformation(origin = {108, -98}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-6, -98}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Sources.RealExpression qDA(y = pipeDA.flowModel.m_flows[1] / rhoN * 3600) annotation(
      Placement(visible = true, transformation(origin = {76, -116}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput qDA_Nm3h annotation(
      Placement(visible = true, transformation(origin = {108, -114}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {20, -98}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
  equation
    connect(qE_kgs.y, consumerE.m_flow_in) annotation(
      Line(points = {{-24, 90}, {-2, 90}, {-2, 76}}, color = {0, 0, 127}));
    connect(pipeAE.port_b, consumerE.ports[1]) annotation(
      Line(points = {{-10, 44}, {-10, 56}}, color = {0, 127, 255}));
    connect(qDA.y, qDA_Nm3h) annotation(
      Line(points = {{88, -116}, {100, -116}, {100, -114}, {108, -114}}, color = {0, 0, 127}));
    connect(qCD.y, qCD_Nm3h) annotation(
      Line(points = {{87, -98}, {108, -98}}, color = {0, 0, 127}));
    connect(qBC.y, qBC_Nm3h) annotation(
      Line(points = {{87, -82}, {108, -82}}, color = {0, 0, 127}));
    connect(qAB.y, qAB_Nm3h) annotation(
      Line(points = {{87, -68}, {108, -68}}, color = {0, 0, 127}));
    connect(qSA.y, qSA_Nm3h) annotation(
      Line(points = {{87, -50}, {106, -50}}, color = {0, 0, 127}));
    connect(pH.y, pH_kPaG) annotation(
      Line(points = {{88, -30}, {98, -30}, {98, -30}, {106, -30}}, color = {0, 0, 127}));
    connect(pG.y, pG_kPaG) annotation(
      Line(points = {{88, -12}, {98, -12}, {98, -12}, {104, -12}}, color = {0, 0, 127}));
    connect(pF.y, pF_kPaG) annotation(
      Line(points = {{88, 8}, {98, 8}, {98, 8}, {104, 8}}, color = {0, 0, 127}));
    connect(pE.y, pE_kPaG) annotation(
      Line(points = {{87, 26}, {106, 26}}, color = {0, 0, 127}));
    connect(pD.y, pD_kPaG) annotation(
      Line(points = {{88, 42}, {100, 42}, {100, 42}, {106, 42}}, color = {0, 0, 127}));
    connect(pC.y, pC_kPaG) annotation(
      Line(points = {{88, 58}, {98, 58}, {98, 58}, {106, 58}}, color = {0, 0, 127}));
    connect(pB.y, pB_kPaG) annotation(
      Line(points = {{88, 74}, {98, 74}, {98, 74}, {106, 74}}, color = {0, 0, 127}));
    connect(pA.y, pA_kPaG) annotation(
      Line(points = {{87, 90}, {106, 90}}, color = {0, 0, 127}));
    connect(qH_kgs.y, consumerH.m_flow_in) annotation(
      Line(points = {{-25, -94}, {-18, -94}, {-18, -88}}, color = {0, 0, 127}));
    connect(qG_kgs.y, consumerG.m_flow_in) annotation(
      Line(points = {{25, -94}, {32, -94}, {32, -88}}, color = {0, 0, 127}));
    connect(pipeCG.port_b, consumerG.ports[1]) annotation(
      Line(points = {{40, -62}, {40, -68}}, color = {0, 127, 255}));
    connect(consumerH.ports[1], pipeDH.port_b) annotation(
      Line(points = {{-10, -68}, {-10, -62}}, color = {0, 127, 255}));
    connect(pipeDH.port_a, pipeCD.port_b) annotation(
      Line(points = {{-10, -42}, {-10, -32}, {4, -32}}, color = {0, 127, 255}));
    connect(pipeBC.port_b, pipeCG.port_a) annotation(
      Line(points = {{40, -20}, {40, -42}}, color = {0, 127, 255}));
    connect(pipeCD.port_b, pipeDA.port_a) annotation(
      Line(points = {{4, -32}, {-10, -32}, {-10, -20}}, color = {0, 127, 255}));
    connect(pipeBC.port_b, pipeCD.port_a) annotation(
      Line(points = {{40, -20}, {40, -32}, {24, -32}}, color = {0, 127, 255}));
    connect(pipeAB.port_b, pipeBC.port_a) annotation(
      Line(points = {{24, 14}, {40, 14}, {40, 0}}, color = {0, 127, 255}));
    connect(pipeDA.port_b, pipeSA.port_b) annotation(
      Line(points = {{-10, 0}, {-10, 14}, {-22, 14}}, color = {0, 127, 255}));
    connect(pipeAB.port_a, pipeSA.port_b) annotation(
      Line(points = {{4, 14}, {-22, 14}}, color = {0, 127, 255}));
    connect(pipeAB.port_b, pipeBF.port_a) annotation(
      Line(points = {{24, 14}, {40, 14}, {40, 24}}, color = {0, 127, 255}));
    connect(pS_Pa.y, governor.p_in) annotation(
      Line(points = {{-79, 22}, {-72, 22}}, color = {0, 0, 127}));
    connect(governor.ports[1], pipeSA.port_a) annotation(
      Line(points = {{-50, 14}, {-42, 14}}, color = {0, 127, 255}));
    connect(pipeSA.port_b, pipeAE.port_a) annotation(
      Line(points = {{-22, 14}, {-10, 14}, {-10, 24}}, color = {0, 127, 255}));
    connect(pipeBF.port_b, consumerF.ports[1]) annotation(
      Line(points = {{40, 44}, {40, 56}}, color = {0, 127, 255}));
    connect(consumerF.m_flow_in, qF_kgs.y) annotation(
      Line(points = {{48, 76}, {48, 90}, {27, 90}}, color = {0, 0, 127}));
    annotation(
      Icon(graphics = {Rectangle(origin = {0, 2}, extent = {{-100, 98}, {100, -100}}), Text(origin = {-51, 72}, extent = {{-25, 24}, {-3, 0}}, textString = "pS"), Text(origin = {-52, 40}, extent = {{-26, 26}, {0, 0}}, textString = "qE"), Text(origin = {73, 85}, extent = {{-11, 17}, {9, -13}}, textString = "pA"), Text(origin = {-70, -90}, extent = {{-26, 26}, {-4, 4}}, textString = "qSA"), Text(origin = {75, -13}, extent = {{-11, 17}, {9, -17}}, textString = "pE"), Text(origin = {-50, -54}, extent = {{-26, 26}, {0, 0}}, textString = "qF"), Text(origin = {-52, 10}, extent = {{-26, 26}, {0, 0}}, textString = "qG"), Text(origin = {-52, -24}, extent = {{-26, 26}, {0, 0}}, textString = "qH"), Text(origin = {73, 59}, extent = {{-11, 17}, {9, -15}}, textString = "pB"), Text(origin = {75, 33}, extent = {{-11, 17}, {9, -15}}, textString = "pC"), Text(origin = {75, 9}, extent = {{-11, 17}, {9, -15}}, textString = "pD"), Text(origin = {75, -35}, extent = {{-11, 17}, {9, -17}}, textString = "pF"), Text(origin = {75, -59}, extent = {{-11, 17}, {9, -17}}, textString = "pG"), Text(origin = {73, -83}, extent = {{-11, 17}, {9, -17}}, textString = "pH"), Text(origin = {-44, -90}, extent = {{-26, 26}, {-4, 4}}, textString = "qAB"), Text(origin = {-18, -90}, extent = {{-26, 26}, {-4, 4}}, textString = "qBC"), Text(origin = {8, -90}, extent = {{-26, 26}, {-4, 4}}, textString = "qCD"), Text(origin = {34, -90}, extent = {{-26, 26}, {-4, 4}}, textString = "qDA")}, coordinateSystem(initialScale = 0.1)),
      __OpenModelica_simulationFlags(lv = "LOG_STATS", outputFormat = "mat", s = "dassl"),
      Diagram(graphics = {Text(origin = {-52, -14}, extent = {{-16, 16}, {2, 2}}, textString = "S"), Text(origin = {-8, -2}, extent = {{-16, 16}, {2, 2}}, textString = "A"), Text(origin = {42, -2}, extent = {{-16, 16}, {2, 2}}, textString = "B"), Text(origin = {42, -36}, extent = {{-16, 16}, {2, 2}}, textString = "C"), Text(origin = {-8, -36}, extent = {{-16, 16}, {2, 2}}, textString = "D"), Text(origin = {-14, 42}, extent = {{-16, 16}, {2, 2}}, textString = "E"), Text(origin = {38, 44}, extent = {{-16, 16}, {2, 2}}, textString = "F"), Text(origin = {36, -74}, extent = {{-16, 16}, {2, 2}}, textString = "G"), Text(origin = {-12, -74}, extent = {{-16, 16}, {2, 2}}, textString = "H")}));
  end Network4;

    model Network4Test
        Modelica.Blocks.Sources.Constant pS(k = 1.5) annotation(
            Placement(visible = true, transformation(origin = {-42, 64}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant qE(k = 200) annotation(
            Placement(visible = true, transformation(origin = {-62, 36}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        GasPipingSystem.Network4 network11 annotation(
            Placement(visible = true, transformation(origin = {18, -6}, extent = {{-28, -28}, {28, 28}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant qF(k = 50) annotation(
            Placement(visible = true, transformation(origin = {-62, 4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant qG(k = 150) annotation(
            Placement(visible = true, transformation(origin = {-62, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant qH(k = 200) annotation(
            Placement(visible = true, transformation(origin = {-52, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
        connect(qG.y, network11.qG_Nm3h) annotation(
            Line(points = {{-50, -30}, {-32, -30}, {-32, -8}, {-8, -8}}, color = {0, 0, 127}));
        connect(qH.y, network11.qH_Nm3h) annotation(
            Line(points = {{-41, -66}, {-24, -66}, {-24, -16}, {-8, -16}, {-8, -15}}, color = {0, 0, 127}));
        connect(qF.y, network11.qF_Nm3h) annotation(
            Line(points = {{-51, 4}, {-31.5, 4}, {-31.5, 0}, {-8, 0}}, color = {0, 0, 127}));
        connect(pS.y, network11.pS_kPaG) annotation(
            Line(points = {{-31, 64}, {-22.5, 64}, {-22.5, 16}, {-8, 16}}, color = {0, 0, 127}));
        connect(qE.y, network11.qE_Nm3h) annotation(
            Line(points = {{-51, 36}, {-25.5, 36}, {-25.5, 8}, {-8, 8}}, color = {0, 0, 127}));
        annotation(
            __OpenModelica_simulationFlags(lv = "LOG_STATS", outputFormat = "mat", s = "dassl"));
    end Network4Test;
  

      model Network3
              import SI = Modelica.SIunits;
              replaceable package Medium = Modelica.Media.IdealGases.SingleGases.CH4;
              parameter SI.Density rhoN = Medium.density(Medium.setState_pT(101325, 273.15));
              Modelica.Blocks.Sources.RealExpression pA(y = (pipeSA.port_b.p - 101325) / 1000) annotation(
                      Placement(visible = true, transformation(origin = {74, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Blocks.Sources.RealExpression qSA(y = pipeSA.flowModel.m_flows[1] / rhoN * 3600) annotation(
                      Placement(visible = true, transformation(origin = {78, -8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Fluid.Sources.Boundary_pT governor(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), T = 298.15, nPorts = 1, use_p_in = true) annotation(
                      Placement(visible = true, transformation(origin = {-50, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Fluid.Pipes.StaticPipe pipeSA(redeclare package Medium = Medium, diameter = 0.3, length = 300) annotation(
                      Placement(visible = true, transformation(origin = {-18, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Fluid.Sources.MassFlowSource_T consumerE(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), nPorts = 1, use_m_flow_in = true) annotation(
                      Placement(visible = true, transformation(origin = {-2, 56}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
              Modelica.Blocks.Sources.RealExpression pS_Pa(y = pS_kPaG * 1000 + 101325) annotation(
                      Placement(visible = true, transformation(origin = {-84, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Blocks.Sources.RealExpression qE_kgs(y = -qE_Nm3h * rhoN / 3600) annotation(
                      Placement(visible = true, transformation(origin = {-12, 84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              inner Modelica.Fluid.System system annotation(
                      Placement(visible = true, transformation(origin = {-50, 84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Blocks.Interfaces.RealInput pS_kPaG annotation(
                      Placement(visible = true, transformation(origin = {-82, 86}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-98, 82}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
              Modelica.Blocks.Interfaces.RealInput qE_Nm3h annotation(
                      Placement(visible = true, transformation(origin = {-82, 58}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-96, 52}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
              Modelica.Blocks.Interfaces.RealOutput qSA_Nm3h annotation(
                      Placement(visible = true, transformation(origin = {106, -8}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-66, -102}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
              Modelica.Blocks.Interfaces.RealOutput pA_kPaG annotation(
                      Placement(visible = true, transformation(origin = {104, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {102, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Fluid.Pipes.StaticPipe pipeAE(redeclare package Medium = Medium, diameter = 0.0216, length = 10, nParallel = 40) annotation(
                      Placement(visible = true, transformation(origin = {-2, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
              Modelica.Blocks.Interfaces.RealOutput pE_kPaG annotation(
                      Placement(visible = true, transformation(origin = {104, 54}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Blocks.Sources.RealExpression pE(y = (pipeAE.port_b.p - 101325) / 1000) annotation(
                      Placement(visible = true, transformation(origin = {76, 54}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Blocks.Sources.RealExpression qAB(y = pipeAB.flowModel.m_flows[1] / rhoN * 3600) annotation(
                      Placement(visible = true, transformation(origin = {78, -26}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Blocks.Interfaces.RealOutput qAB_Nm3h annotation(
                      Placement(visible = true, transformation(origin = {106, -26}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-28, -100}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
              Modelica.Fluid.Pipes.StaticPipe pipeAB(redeclare package Medium = Medium, diameter = 0.15, length = 300)  annotation(
                      Placement(visible = true, transformation(origin = {20, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Fluid.Pipes.StaticPipe pipeBF(redeclare package Medium = Medium, diameter = 0.0216, length = 10, nParallel = 10)  annotation(
                      Placement(visible = true, transformation(origin = {34, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
              Modelica.Fluid.Sources.MassFlowSource_T consumerF(redeclare package Medium = Medium(BaseProperties(p(nominal = 1000000.0))), nPorts = 1, use_m_flow_in = true)  annotation(
                      Placement(visible = true, transformation(origin = {34, 56}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
              Modelica.Blocks.Sources.RealExpression qF_kgs(y = -qF_Nm3h * rhoN / 3600) annotation(
                      Placement(visible = true, transformation(origin = {28, 84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
              Modelica.Blocks.Interfaces.RealInput qF_Nm3h annotation(
                      Placement(visible = true, transformation(origin = {-82, 34}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-96, 22}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
      Modelica.Blocks.Sources.RealExpression pB(y = (pipeAB.port_b.p - 101325) / 1000) annotation(
                      Placement(visible = true, transformation(origin = {76, 72}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput pB_kPaG annotation(
                      Placement(visible = true, transformation(origin = {104, 74}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, 56}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.RealExpression pF(y = (pipeBF.port_b.p - 101325) / 1000) annotation(
                      Placement(visible = true, transformation(origin = {76, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput pF_kPaG annotation(
                      Placement(visible = true, transformation(origin = {104, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {106, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
              connect(pF.y, pF_kPaG) annotation(
                      Line(points = {{88, 34}, {104, 34}}, color = {0, 0, 127}));
              connect(pB.y, pB_kPaG) annotation(
                      Line(points = {{88, 72}, {96, 72}, {96, 74}, {104, 74}}, color = {0, 0, 127}));
              connect(pE.y, pE_kPaG) annotation(
                      Line(points = {{87, 54}, {97, 54}, {97, 54}, {103, 54}}, color = {0, 0, 127}));
              connect(pipeBF.port_b, consumerF.ports[1]) annotation(
                      Line(points = {{34, 30}, {34, 30}, {34, 46}, {34, 46}}, color = {0, 127, 255}));
              connect(pipeAB.port_b, pipeBF.port_a) annotation(
                      Line(points = {{30, -2}, {34, -2}, {34, 10}, {34, 10}}, color = {0, 127, 255}));
              connect(pipeSA.port_b, pipeAB.port_a) annotation(
                      Line(points = {{-8, -2}, {8, -2}, {8, -2}, {10, -2}}, color = {0, 127, 255}));
              connect(qF_kgs.y, consumerF.m_flow_in) annotation(
                      Line(points = {{40, 84}, {40, 75}, {42, 75}, {42, 66}}, color = {0, 0, 127}));
              connect(qAB.y, qAB_Nm3h) annotation(
                      Line(points = {{89, -26}, {106, -26}}, color = {0, 0, 127}));
              connect(qSA.y, qSA_Nm3h) annotation(
                      Line(points = {{89, -8}, {106, -8}}, color = {0, 0, 127}));
              connect(pA.y, pA_kPaG) annotation(
                      Line(points = {{85, 90}, {104, 90}}, color = {0, 0, 127}));
              connect(pipeAE.port_b, consumerE.ports[1]) annotation(
                      Line(points = {{-2, 30}, {0, 30}, {0, 48}, {-2, 48}, {-2, 46}}, color = {0, 127, 255}));
              connect(pipeSA.port_b, pipeAE.port_a) annotation(
                      Line(points = {{-8, -2}, {-2, -2}, {-2, 10}, {-2, 10}}, color = {0, 127, 255}));
              connect(pS_Pa.y, governor.p_in) annotation(
                      Line(points = {{-73, 6}, {-63, 6}, {-63, 6}, {-63, 6}}, color = {0, 0, 127}));
              connect(governor.ports[1], pipeSA.port_a) annotation(
                      Line(points = {{-40, -2}, {-34, -2}, {-34, -2}, {-28, -2}, {-28, -2}, {-28, -2}, {-28, -2}, {-28, -2}}, color = {0, 127, 255}));
              connect(qE_kgs.y, consumerE.m_flow_in) annotation(
                      Line(points = {{0, 84}, {6, 84}, {6, 66}, {6, 66}}, color = {0, 0, 127}));
              annotation(
          Icon(graphics = {Rectangle(origin = {0, 2}, extent = {{-100, 98}, {100, -102}}), Text(origin = {-57, 72}, extent = {{-25, 24}, {-3, 0}}, textString = "pS"), Text(origin = {-56, 42}, extent = {{-26, 26}, {0, 0}}, textString = "qE"), Text(origin = {73, 83}, extent = {{-11, 17}, {13, -19}}, textString = "pA"), Text(origin = { -56, -86}, extent = {{-26, 26}, {4, -4}}, textString = "qSA"), Text(origin = {77, 29}, extent = {{-11, 17}, {13, -19}}, textString = "pE"), Text(origin = {-18, -86}, extent = {{-26, 26}, {4, -4}}, textString = "qAB"), Text(origin = {-56, 10}, extent = {{-26, 26}, {0, 0}}, textString = "qF"), Text(origin = {77, 57}, extent = {{-11, 17}, {13, -19}}, textString = "pB"), Text(origin = {77, 5}, extent = {{-11, 17}, {13, -19}}, textString = "pE")}, coordinateSystem(initialScale = 0.1)),
          __OpenModelica_simulationFlags(lv = "LOG_STATS", outputFormat = "mat", s = "dassl"));
      end Network3;
  

    model Network3Test
        Modelica.Blocks.Sources.Constant pA(k = 1.5) annotation(
            Placement(visible = true, transformation(origin = {-50, 36}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant qE(k = 200) annotation(
            Placement(visible = true, transformation(origin = {-50, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        GasPipingSystem.Network3 network11 annotation(
            Placement(visible = true, transformation(origin = {14, 14}, extent = {{-28, -28}, {28, 28}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant qF(k = 50) annotation(
      Placement(visible = true, transformation(origin = {-50, -26}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
    connect(qF.y, network11.qF_Nm3h) annotation(
      Line(points = {{-38, -26}, {-24, -26}, {-24, 22}, {-14, 22}, {-14, 20}, {-12, 20}}, color = {0, 0, 127}));
        connect(pA.y, network11.pS_kPaG) annotation(
      Line(points = {{-39, 36}, {-28.5, 36}, {-28.5, 37}, {-13, 37}}, color = {0, 0, 127}));
        connect(qE.y, network11.qE_Nm3h) annotation(
      Line(points = {{-39, 6}, {-32, 6}, {-32, 29}, {-13, 29}}, color = {0, 0, 127}));
        annotation(
            __OpenModelica_simulationFlags(lv = "LOG_STATS", outputFormat = "mat", s = "dassl"));
    end Network3Test;
  
  annotation(
    uses(Modelica(version = "3.2.2")));
end GasPipingSystem;